@@ -120,6 +120,7 @@ class GXDLMSSettings:
         #Quality of service.
         self.qualityOfService = 0
         self.useUtc2NormalTime = False
+        self.increaseInvocationCounterForGMacAuthentication = False
         self.dateTimeSkips = DateTimeSkips.NONE
         self.standard = Standard.DLMS
         self.negotiatedConformance = Conformance.NONE
@@ -128,7 +129,7 @@ class GXDLMSSettings:
         self.senderFrame = 0
         self.command = 0
         self.commandType = 0
-        self.useUtc2NormalTime = False
+        self.useCustomChallenge = False
 
     #
     # Client to Server challenge.
